import { Body, Controller, Delete, Get, Param, Post, Put } from '@nestjs/common';
import { EntriesService } from '~/entries/entries.service';
import { Entry } from '~/entries/interfaces/entry.type';

@Controller('api/entries')
export class EntriesController {
	constructor(private entriesService: EntriesService) {}

	@Put()
	async createEntry(): Promise<Entry> {
		return this.entriesService.create();
	}

	@Get(':id')
	async getEntry(@Param('id') id: string): Promise<Entry> {
		return this.entriesService.getEntry(id);
	}

	@Post(':id')
	async updateEntry(@Param('id') id: string, @Body() data: JSON): Promise<Entry> {
		return this.entriesService.updateEntry(id, data);
	}

	@Delete(':id')
	async deleteEntry(@Param('id') id: string): Promise<boolean> {
		return this.entriesService.deleteEntry(id);
	}
}
